@@ -10,10 +10,12 @@ import re
 import sys
 import time
 import datetime
+import shutil
 from os.path import isfile
 from pathlib import Path
 
 import click
+
 import pkg_resources
 import semantic_version
 
@@ -26,15 +28,28 @@ from apio.resources import Resources
 
 
 class SCons:
-    """DOC: TODO"""
+    """Class for managing the scons tools"""
 
     def __init__(self, project_dir=""):
+        """Initialization:
+        * project_dir: path where the sources are located
+          If not given, the curent working dir is used
+        """
+
+        # -- Read the apio profile file
         self.profile = Profile()
+
+        # -- Read the apio resources
         self.resources = Resources()
 
+        # -- Project path is given
         if project_dir is not None:
-            # Move to project dir
+
+            # Check if it is a correct folder
+            # (or create a new one)
             project_dir = util.check_dir(project_dir)
+
+            # Change to that folder
             os.chdir(project_dir)
 
     @util.command
@@ -43,18 +58,27 @@ class SCons:
 
         try:
             __, __, arch = process_arguments(args, self.resources)
+
+        # -- No architecture given: Uses ice40 as default
         except Exception:
             arch = "ice40"
 
-        return self.run("-c", arch=arch, packages=["scons"])
+        # --Clean the project: run scons -c (with aditional arguments)
+        return self.run("-c", arch=arch)
 
     @util.command
     def verify(self, args):
-        """DOC: TODO"""
+        """Executes scons for verifying"""
 
+        # -- Split the arguments
         __, __, arch = process_arguments(args, self.resources)
+
+        # -- Execute scons!!!
+        # -- The packages to check are passed
         return self.run(
-            "verify", arch=arch, packages=["scons", "iverilog", "yosys"]
+            "verify",
+            arch=arch,
+            packages=["oss-cad-suite"],
         )
 
     @util.command
@@ -72,7 +96,10 @@ class SCons:
             }
         )
         return self.run(
-            "lint", var, arch=arch, packages=["scons", "verilator", "yosys"]
+            "lint",
+            var,
+            arch=arch,
+            packages=["oss-cad-suite"],
         )
 
     @util.command
@@ -83,16 +110,24 @@ class SCons:
         return self.run(
             "sim",
             arch=arch,
-            packages=["scons", "iverilog", "yosys", "gtkwave"],
+            packages=["oss-cad-suite", "gtkwave"],
         )
 
     @util.command
     def build(self, args):
-        """DOC: TODO"""
+        """Build the circuit"""
 
+        # -- Split the arguments
         var, board, arch = process_arguments(args, self.resources)
+
+        # -- Execute scons!!!
+        # -- The packages to check are passed
         return self.run(
-            "build", var, board, arch, packages=["scons", "yosys", arch]
+            "build",
+            var,
+            board,
+            arch,
+            packages=["oss-cad-suite"],
         )
 
     @util.command
@@ -100,16 +135,16 @@ class SCons:
         """DOC: TODO"""
 
         var, board, arch = process_arguments(args, self.resources)
-        return self.run(
-            "time", var, board, arch, packages=["scons", "yosys", arch]
-        )
+        return self.run("time", var, board, arch, packages=["oss-cad-suite"])
 
     @util.command
     def upload(self, args, serial_port, ftdi_id, sram, flash):
-        """DOC: TODO"""
+        """Upload the circuit to the board"""
 
+        # -- Split the arguments
         var, board, arch = process_arguments(args, self.resources)
 
+        # -- Get the programmer for that board
         programmer = self.get_programmer(
             board, serial_port, ftdi_id, sram, flash
         )
@@ -117,7 +152,11 @@ class SCons:
         var += [f"prog={programmer}"]
 
         return self.run(
-            "upload", var, board, arch, packages=["scons", "yosys", arch]
+            "upload",
+            var,
+            board,
+            arch,
+            packages=["oss-cad-suite"],
         )
 
     def get_programmer(self, board, ext_serial, ext_ftdi_id, sram, flash):
@@ -252,13 +291,21 @@ class SCons:
 
         programmer = content.get("command")
 
-        # Add args
-        if content.get("args"):
-            programmer += " {}".format(content.get("args"))
+        # dfu-util needs extra args first
+        if programmer.startswith("dfu-util"):
+            if prog_info.get("extra_args"):
+                programmer += " {}".format(prog_info.get("extra_args"))
 
-        # Add extra args
-        if prog_info.get("extra_args"):
-            programmer += " {}".format(prog_info.get("extra_args"))
+            if content.get("args"):
+                programmer += " {}".format(content.get("args"))
+        else:
+            # Add args
+            if content.get("args"):
+                programmer += " {}".format(content.get("args"))
+
+            # Add extra args
+            if prog_info.get("extra_args"):
+                programmer += " {}".format(prog_info.get("extra_args"))
 
         # Enable SRAM programming
         if sram:
@@ -390,7 +437,7 @@ class SCons:
         return None
 
     def run(self, command, variables=[], board=None, arch=None, packages=[]):
-        """Executes scons for building"""
+        """Executes scons"""
 
         # -- Check if in the current project a custom SConstruct file
         # is being used. We fist build the full name (with the full path)
@@ -431,7 +478,9 @@ class SCons:
         return self._execute_scons(command, variables, board)
 
     def _execute_scons(self, command, variables, board):
-        terminal_width, _ = click.get_terminal_size()
+        """Execute the scons builder"""
+
+        terminal_width, _ = shutil.get_terminal_size()
         start_time = time.time()
 
         if command in ("build", "upload", "time"):
@@ -448,15 +497,17 @@ class SCons:
             )
             click.secho("-" * terminal_width, bold=True)
 
+        scons_command = ["scons"] + ["-Q", command] + variables
         if self.profile.get_verbose_mode() > 0:
             click.secho(
                 "Executing: {}".format(
-                    " ".join(util.scons_command + ["-Q", command] + variables)
+                    " ".join(util.exec_command(scons_command))
                 )
             )
 
+        # -- Execute the scons builder
         result = util.exec_command(
-            util.scons_command + ["-Q", command] + variables,
+            scons_command,
             stdout=util.AsyncPipe(self._on_stdout),
             stderr=util.AsyncPipe(self._on_stderr),
         )
