@@ -17,7 +17,7 @@ import locale
 import platform
 import subprocess
 from threading import Thread
-from os.path import isdir, isfile, join, dirname, exists, normpath
+from os.path import isdir, isfile, join, dirname, exists
 from pathlib import Path
 
 import click
@@ -351,7 +351,7 @@ def setup_environment():
     # --- Get the table with the paths of all the apio packages
     base_dir = get_base_dir()
 
-    # --- Get the table with tha paths of all the executables
+    # --- Get the table with the paths of all the executables
     # --- of the apio packages
     bin_dir = get_bin_dir_table(base_dir)
 
@@ -364,42 +364,61 @@ def setup_environment():
 def set_env_variables(base_dir, bin_dir):
     """Set the environment variables"""
 
-    # Give the priority to the python packages installed with apio
-    os.environ["PATH"] = os.pathsep.join([get_bin_dir(), os.environ["PATH"]])
+    # -- Get the current system PATH
+    path = os.environ["PATH"]
 
-    # Give the priority to the packages installed by apio
-    os.environ["PATH"] = os.pathsep.join(
-        [
-            bin_dir.get(OSS_CAD_SUITE),
-            bin_dir.get(YOSYS),
-            bin_dir.get(ICE40),
-            bin_dir.get(ECP5),
-            bin_dir.get(IVERILOG),
-            bin_dir.get(VERILATOR),
-            bin_dir.get(FUJPROG),
-            bin_dir.get(ICESPROG),
-            bin_dir.get(DFU),
-            bin_dir.get(SYSTEM),
-            os.environ["PATH"],
-        ]
+    # -- Add the packages to the path. The first packages added
+    # -- have the lowest priority. The latest the highest
+
+    # -- Add the gtkwave to the path if installed,
+    # -- but only for windows platforms
+    if platform.system() == "Windows":
+
+        # -- Gtkwave package is installed
+        if bin_dir[GTKWAVE] != "":
+            path = os.pathsep.join([bin_dir.get(GTKWAVE), path])
+
+    # -- Add the binary folders of the installed packages
+    # -- to the path, except for the OSS_CAD_SUITE package
+    for pack in base_dir:
+        if base_dir[pack] != "" and pack != OSS_CAD_SUITE:
+            path = os.pathsep.join([bin_dir[pack], path])
+
+    # -- Add the OSS_CAD_SUITE package to the path
+    # -- if installed (Maximum priority)
+    if base_dir[OSS_CAD_SUITE] != "":
+
+        # -- Get the lib folder (where the shared libraries are located)
+        oss_cad_suite_lib = str(Path(base_dir[OSS_CAD_SUITE]) / "lib")
+
+        # -- Add the lib folder
+        path = os.pathsep.join([oss_cad_suite_lib, path])
+        path = os.pathsep.join([bin_dir[OSS_CAD_SUITE], path])
+
+    # Add the virtual python environment to the path
+    os.environ["PATH"] = path
+
+    # print(f" get_bin_dir(): {get_bin_dir()}")
+
+    # -- DEBUG
+    print()
+    print(f"PATH: {os.environ['PATH']}")
+    print()
+
+    # Add other environment variables
+
+    os.environ["IVL"] = str(Path(base_dir[OSS_CAD_SUITE]) / "lib" / "ivl")
+
+    os.environ["ICEBOX"] = str(
+        Path(base_dir[OSS_CAD_SUITE]) / "share" / "icebox"
     )
 
-    # -- Add the gtkwave to the path, only in windows
-    if platform.system() == "Windows":
-        os.environ["PATH"] = os.pathsep.join(
-            [bin_dir.get(GTKWAVE), os.environ["PATH"]]
-        )
-
-    # Add environment variables
-    if not config_data:  # /etc/apio.json file does not exist
-        os.environ["IVL"] = safe_join(base_dir.get(IVERILOG), "lib", "ivl")
-
-    os.environ["ICEBOX"] = str(Path(base_dir.get(ICE40)) / "share" / "icebox")
-
-    os.environ["TRELLIS"] = str(Path(base_dir.get(ECP5)) / "share" / "trellis")
+    os.environ["TRELLIS"] = str(
+        Path(base_dir[OSS_CAD_SUITE]) / "share" / "trellis"
+    )
 
     os.environ["YOSYS_LIB"] = str(
-        Path(base_dir.get(YOSYS)) / "share" / "yosys"
+        Path(base_dir[OSS_CAD_SUITE]) / "share" / "yosys"
     )
 
 
@@ -418,7 +437,7 @@ def resolve_packages(packages, installed_packages, spec_packages):
     # -- Check packages
     check = True
     for package in packages:
-        
+
         version = installed_packages.get(package, {}).get("version", "")
 
         spec_version = spec_packages.get(package, "")
@@ -433,18 +452,14 @@ def resolve_packages(packages, installed_packages, spec_packages):
         # --- Set the system env. variables
         set_env_variables(base_dir, bin_dir)
 
-        global scons_command
-        scons_command = [
-            normpath(sys.executable),
-            safe_join(bin_dir[SCONS], "scons"),
-        ]
-
     return check
 
 
 def get_base_dir():
     """Return the table with the local paths of the apio packages
-    installed on the system"""
+    installed on the system. If the packages is not installed,
+    the path is ''
+    """
 
     # -- Create the table:
     # --  Package Name  :  Folder (string)
@@ -684,23 +699,34 @@ def mkdir(path):
 
 
 def check_dir(_dir):
-    """DOC: TODO"""
+    """Check if the given path is a folder. If no path is given
+    the current path is used"""
 
+    # -- If no path is given, get the current working directory
     if _dir is None:
         _dir = os.getcwd()
 
+    # -- Check if the path is a file or a folder
     if isfile(_dir):
+
+        # -- It is a file! Error! Exit!
         click.secho(
-            "Error: project directory is already a file: {0}".format(_dir),
-            fg="red",
+            f"Error: project directory is already a file: {_dir}", fg="red"
         )
+
         sys.exit(1)
 
+    # -- If the folder does not exist....
     if not exists(_dir):
-        try:
-            os.makedirs(_dir)
-        except OSError:
-            pass
+
+        # -- Warning
+        click.secho(f"Warning: The path does not exist: {_dir}", fg="yellow")
+
+        # -- Create the folder
+        click.secho(f"Creating folder: {_dir}")
+        os.makedirs(_dir)
+
+    # -- Return the path
     return _dir
 
 
