@@ -16,4 +16,4 @@ def test_time_board(clirunner, configenv):
         result = clirunner.invoke(cmd_time, ['--board', 'icezum'])
         assert result.exit_code != 0
         if result.exit_code == 1:
-            assert 'apio install yosys' in result.output
+            assert 'apio install oss-cad-suite' in result.output
