@@ -7,4 +7,4 @@ def test_verify(clirunner, configenv):
         result = clirunner.invoke(cmd_verify, ['--board', 'icezum'])
         assert result.exit_code != 0
         if result.exit_code == 1:
-            assert 'apio install iverilog' in result.output
+            assert 'apio install oss-cad-suite' in result.output
